@@ -10,14 +10,17 @@ import typing_extensions
 
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_dynamodb._jsii
+import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_rds._jsii
 import aws_cdk.aws_s3_assets._jsii
+import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-appsync", "1.70.0", __name__[0:-6], "aws-appsync@1.70.0.jsii.tgz"
+    "@aws-cdk/aws-appsync", "1.78.0", __name__[0:-6], "aws-appsync@1.78.0.jsii.tgz"
 )
 
 __all__ = [
